@@ -56,10 +56,7 @@ async def dump_main(args):
 
         await dump(roots, io, params)
     finally:
-        try:
-            await asyncio.wait_for(pool.close(), 60)
-        except asyncio.TimeoutError:
-            logging.error("Pool failed to close within 60s")
+        await pool.close()
 
 
 async def _init_connection(conn):
